import argparse
from nemo.collections.asr.models import EncDecMultiTaskModel
 

def main(channel_selector):
      print('Using channel selector:', channel_selector)

      # load model
      canary_model = EncDecMultiTaskModel.from_pretrained('nvidia/canary-1b')
      
      # update dcode params
      decode_cfg = canary_model.cfg.decoding
      decode_cfg.beam.beam_size = 1
      canary_model.change_decoding_strategy(decode_cfg)

      mc_manifest = './mc_manifest.json'

      # run transcribe
      predicted_text = canary_model.transcribe(
            mc_manifest,
            batch_size=1,  # batch size to run the inference with
            channel_selector=channel_selector,  # channel
      )

      # print transcriptions
      print('Transcriptions:\n')
      for n, pred in enumerate(predicted_text):
            print(f'example {n:02}:', pred)


if __name__ == '__main__':
      """
      Test using
            1) python test_transcribe.py --channel-selector 0
            2) python test_transcribe.py --channel-selector 1
            3) python test_transcribe.py --channel-selector reference_channel

      The following examples will raise an error:
            1) python test_transcribe.py # run without --channel-selector
            2) python test_transcribe.py --channel-selector 2
            3) python test_transcribe.py --channel_selector non_existent_field
      """
      parser = argparse.ArgumentParser()
      parser.add_argument('--channel-selector', type=str, default=None)
      args = parser.parse_args()

      if args.channel_selector is None or args.channel_selector == 'None':
            channel_selector = None
      elif args.channel_selector.isdecimal():
            channel_selector = int(args.channel_selector)
      else:
            channel_selector = args.channel_selector

      main(channel_selector=channel_selector)